pub struct RuleConfig {Show 25 fields
pub min_quality_signal: u32,
pub min_modularity: f64,
pub min_acyclicity: f64,
pub min_depth: f64,
pub min_equality: f64,
pub min_redundancy: f64,
pub max_cycles: usize,
pub max_coupling_ratio: f64,
pub max_function_complexity: usize,
pub max_cognitive_complexity: usize,
pub max_file_lines: usize,
pub max_function_lines: usize,
pub no_god_files: bool,
pub high_file_fan_in: usize,
pub high_file_fan_out: usize,
pub large_file_lines: usize,
pub max_large_file_findings: usize,
pub low_call_resolution_min_calls: usize,
pub low_call_resolution_ratio: f64,
pub high_function_fan_in: usize,
pub high_function_fan_out: usize,
pub max_call_hotspot_findings: usize,
pub max_upward_layer_violations: usize,
pub no_tests_detected: bool,
pub language_overrides: BTreeMap<String, LanguageRuleOverride>,
}Fields
min_quality_signal: u32min_modularity: f64min_acyclicity: f64min_depth: f64min_equality: f64min_redundancy: f64max_cycles: usizemax_coupling_ratio: f64max_function_complexity: usizemax_cognitive_complexity: usizemax_file_lines: usizemax_function_lines: usizeno_god_files: boolhigh_file_fan_in: usizehigh_file_fan_out: usizelarge_file_lines: usizemax_large_file_findings: usizelow_call_resolution_min_calls: usizelow_call_resolution_ratio: f64high_function_fan_in: usizehigh_function_fan_out: usizemax_call_hotspot_findings: usizemax_upward_layer_violations: usizeno_tests_detected: boollanguage_overrides: BTreeMap<String, LanguageRuleOverride>Per-language overrides keyed by language_name (case-insensitive).
Each override field, when set, takes precedence over the matching
global field for files in that language. Useful when one language’s
idioms make a global threshold either too strict or too lax (e.g.
Rust match arms inflate cyclomatic vs Python’s flat conditionals).